Database Design
===============

This section is dedicated to designing the database for the system.
Designing a non-relational database can be tricky due to its flexibility, as opposed to
for traditional relational database.
However, we followed a similar approach:
we first analyze which entities need to be represented and
from there, we derive tables for the database accordingly.

.. toctree::
   :maxdepth: 2

   entities/index
   tables/index

